pub struct AddChargeParams {
pub client: Option<i64>,
pub charge: Option<f64>,
pub description: Option<String>,
pub test: bool,
}Expand description
- Adds a Charge to a specific Reseller Client
Parameters for Client::add_charge (wire method addCharge).
Fields
client: Option<i64>ID for a specific Reseller Client (Example: 561115) (required)
charge: Option<f64>Amount of money that will be Debited from the customer (Example: 4.99) (required)
description: Option<String>Charge Description
test: boolSet to true if testing how adding charges works