AddLNPPortParams

Struct AddLNPPortParams 

pub struct AddLNPPortParams {
Show 21 fields pub portType: Option<i64>, pub numbers: Option<String>, pub isPartial: Option<bool>, pub locationType: Option<i64>, pub isMobile: Option<bool>, pub pin: Option<String>, pub btn: Option<String>, pub services: Option<String>, pub tfType: Option<i64>, pub statementName: Option<String>, pub firstName: Option<String>, pub lastName: Option<String>, pub address1: Option<String>, pub address2: Option<String>, pub city: Option<String>, pub zip: Option<String>, pub state: Option<String>, pub country: Option<String>, pub providerName: Option<String>, pub providerAccount: Option<String>, pub notes: Option<String>,
}
- Add one or more numbers to start a portability process.

Parameters for Client::add_lnp_port (wire method addLNPPort).

Fields

portType: Option<i64>

Digits from 1 to 4: 1: United States Local numbers 2: Canadian Local Numbers 3: US/CA Toll Free Numbers 4: United States Fax numbers 5: Canadian Fax Numbers (required)

numbers: Option<String>

DID(s) to port into VoIP.ms network (Example: 5552341234,5552341233). If you are porting more than one number, please separate them with commas. (required)

isPartial: Option<bool>

If you have more then 1 number with your current carrier and not porting them all, choose yes. If you are porting all the numbers, choose no. Please note that you still need to include all numbers you want to port. If you have 2 numbers and want to port both, you need to include both numbers in the list of numbers to port. - (Values: 1 = true, 0 = false) - Default: 0

locationType: Option<i64>

- (Values: 1 = Business, 0 = Residential) - Default: 0

isMobile: Option<bool>

- (Values: 1 = All the numbers are mobile numbers, 0 = false) - Default: 0

pin: Option<String>

PIN Number

btn: Option<String>

[Required If isMobile = 1] BTN: It is the phone number to which all the other numbers of the customer are charged, in a consolidated telephone bill (instead of showing separate charges for each number you own). Please try to find the BTN on your invoice, and if you are unable to do so please contact the current provider to obtain it.

services: Option<String>

[Required If isMobile = 1] Please be specific and describe ALL remaining services with the current carrier. This includes DSL/Data services, Hunt Group services, etc. Any services NOT listed below may be disconnected upon completion of this port order.

tfType: Option<i64>

[Required If portType = 3] Values: 1 - American Carrier, American Callers Only, 2 - American Carrier, American and Canadian Callers allowed, 3 - Canadian Carrier

statementName: Option<String>

This is for Business numbers only. Please type your Company Name if applicable, otherwise leave it blank. (required)

firstName: Option<String>

This is the “Customer First Name” as it appears on the CSR (Customer Service Record) of the losing carrier. Please Enter the first name of the owner of the number or the autorized contact. No company name must be entered in the field. (required)

lastName: Option<String>

This is the “Customer Last Name” as it appears on the CSR (Customer Service Record) of the losing carrier. Please Enter the last name of the owner of the number or the autorized contact. No company name must be entered in the field (required)

address1: Option<String>

This is the “Customer Address” as it appears on the CSR (Customer Service Record) of the losing carrier. (required)

address2: Option<String>

Optional Address information (e.g: Suite 343)

city: Option<String>

This is the “City” as it appears on the CSR (Customer Service Record) of the losing carrier. (required)

zip: Option<String>

This is the “ZIP or Postal Code” as it appears on the CSR (Customer Service Record) of the losing carrier. (required)

state: Option<String>

This is the “State or Province” as it appears on the CSR (Customer Service Record) of the losing carrier. (required)

country: Option<String>

This is the “Country” as it appears on the CSR (Customer Service Record) of the losing carrier. (required)

providerName: Option<String>

The name of your current service provider. (required)

providerAccount: Option<String>

Your Account with your current service provider. (required)

notes: Option<String>

- If you would like to include additional information regarding this port, you can use this parameter.