CreateSubAccountParams

Struct CreateSubAccountParams 

pub struct CreateSubAccountParams {
Show 42 fields pub username: Option<String>, pub protocol: Option<i64>, pub description: Option<String>, pub auth_type: Option<i64>, pub password: Option<String>, pub ip: Option<String>, pub device_type: Option<i64>, pub callerid_number: Option<String>, pub canada_routing: Option<String>, pub lock_international: Option<i64>, pub international_route: Option<i64>, pub music_on_hold: Option<String>, pub language: Option<String>, pub allowed_codecs: Option<String>, pub dtmf_mode: Option<DtmfMode>, pub nat: Option<Nat>, pub sip_traffic: Option<i64>, pub max_expiry: Option<i64>, pub rtp_timeout: Option<i64>, pub rtp_hold_timeout: Option<i64>, pub ip_restriction: Option<String>, pub enable_ip_restriction: Option<bool>, pub pop_restriction: Option<String>, pub enable_pop_restriction: Option<bool>, pub internal_extension: Option<String>, pub internal_voicemail: Option<String>, pub internal_dialtime: Option<String>, pub reseller_client: Option<String>, pub reseller_package: Option<String>, pub reseller_nextbilling: Option<String>, pub reseller_chargesetup: Option<String>, pub send_bye: Option<bool>, pub record_calls: Option<bool>, pub transcribe: Option<bool>, pub transcription_locale: Option<String>, pub transcription_email: Option<String>, pub transcription_start_delay: Option<i64>, pub enable_internal_cnam: Option<bool>, pub internal_cnam: Option<String>, pub dialing_mode: Option<DialingMode>, pub tfcarrier: Option<TollFreeCarrier>, pub internal_extension_location: Option<i64>,
}
- Adds a new Sub Account entry to your Account

Parameters for Client::create_sub_account (wire method createSubAccount).

Fields

username: Option<String>

Username for the Sub Account (Example: ‘VoIP’) (required)

protocol: Option<i64>

Protocol used for the Sub Account (Values from getProtocols) (required)

description: Option<String>

Sub Account Description (Example: ‘VoIP Account’)

auth_type: Option<i64>

Authorization Type Code (Values from getAuthTypes) (required)

password: Option<String>

Sub Account Password (For Password Authentication)

ip: Option<String>

Sub Account IP (For IP Authentication)

device_type: Option<i64>

Device Type Code (Values from getDeviceTypes) (required)

callerid_number: Option<String>

Caller ID Override

canada_routing: Option<String>

Route Code (Values from getRoutes)

lock_international: Option<i64>

Lock International Code (Values from getLockInternational) (required)

international_route: Option<i64>

Route Code (Values from getRoutes) (required)

music_on_hold: Option<String>

Music on Hold Code (Values from getMusicOnHold) (required)

language: Option<String>

Language for system messages, such as “Invalid Option” (Values from getLanguages)

allowed_codecs: Option<String>

List of Allowed Codecs (Values from getAllowedCodecs) Codecs separated by semicolon (Example: ulaw;g729;gsm) (required)

dtmf_mode: Option<DtmfMode>

DTMF Mode Code (Values from getDTMFModes) (required)

nat: Option<Nat>

NAT Mode Code (Values from getNAT) (required)

sip_traffic: Option<i64>

Encrypted SIP Traffic (Boolean: 1/0)

max_expiry: Option<i64>

Max Expiry between 60 and 3600 (Example: 3000)

rtp_timeout: Option<i64>

RTP Time Out between 1 and 3600 (Example: 60)

rtp_hold_timeout: Option<i64>

RTP Hold Time Out between 1 and 3600 (Example: 600)

ip_restriction: Option<String>

List of IP Addresses, IP Addresses/Netmask, or Fully Qualified Domain Names to allow outgoing calls separated by commas (Example: 123.45.3.21,10.255.12.0/22,device.mydomain.com)

enable_ip_restriction: Option<bool>

Enable IP Restriction (Boolean: 1/0)

pop_restriction: Option<String>

List of POP Servers to allow outgoing calls separated by commas (values from getServersInfo. Example: 10,23,45)

enable_pop_restriction: Option<bool>

Enable POP Restriction (Boolean: 1/0)

internal_extension: Option<String>

Sub Account Internal Extension (Example: 1 -> Creates 101)

internal_voicemail: Option<String>

Sub Account Internal Voicemail (Example: 101)

internal_dialtime: Option<String>

Sub Account Internal Dialtime (Example: 60 -> seconds)

reseller_client: Option<String>

Reseller Account ID (Example: 561115)

reseller_package: Option<String>

Reseller Package (Example: 92364)

reseller_nextbilling: Option<String>

Reseller Next Billing Date (Example: ‘2012-12-31’)

reseller_chargesetup: Option<String>

True if you want to charge Package Setup Fee after Save

send_bye: Option<bool>

Send BYE on successful transfer (Boolean: 1/0)

record_calls: Option<bool>

Record Calls (Boolean: 1/0)

transcribe: Option<bool>

Enable Call Transcription (Boolean: 1/0)

transcription_locale: Option<String>

Transcription locale code (values from getLocales, comma separated for more than one locale up to 10 locales)

transcription_email: Option<String>

Call Transcription Email

transcription_start_delay: Option<i64>

Call Transcription Delay Seconds between 0 and 60, Increments of 5 (Example: 10 -> seconds)

enable_internal_cnam: Option<bool>

Enable Internal CallerID

internal_cnam: Option<String>

Internal CallerID Name

dialing_mode: Option<DialingMode>

Allows you to dial outgoing calls using either the NANPA configuration or the E164 configuration. (Values: 0 = Use Main Account Setting, 1 = E164, 2 = NANPA)

tfcarrier: Option<TollFreeCarrier>

This allows you to select the carrier to be used for outgoing calls to toll-free numbers. (Values: -1 = Use main account settings, 0 = Default server setting, 1 = US carrier, 2 = Canadian carrier)

internal_extension_location: Option<i64>

Location group for the internal extension (Values from getLocations)