pub struct CreateVoicemailParams {Show 20 fields
pub digits: Option<i64>,
pub name: Option<String>,
pub password: Option<String>,
pub skip_password: Option<bool>,
pub email: Option<String>,
pub attach_message: Option<bool>,
pub delete_message: Option<bool>,
pub say_time: Option<bool>,
pub timezone: Option<String>,
pub say_callerid: Option<bool>,
pub play_instructions: Option<PlayInstructions>,
pub language: Option<String>,
pub email_attachment_format: Option<EmailAttachmentFormat>,
pub unavailable_message_recording: Option<String>,
pub transcription: Option<bool>,
pub transcription_locale: Option<String>,
pub transcription_redaction: Option<bool>,
pub transcription_sentiment: Option<bool>,
pub transcription_summary: Option<bool>,
pub transcription_format: Option<TranscriptionFormat>,
}Expand description
- Adds a new Voicemail entry to your Account
Parameters for Client::create_voicemail (wire method createVoicemail).
Fields
digits: Option<i64>Digits used to create the voicemail (Example: 01) Minimum 1 digit, maximum 10 digits (required)
name: Option<String>Name for the Mailbox (required)
password: Option<String>Password for the Mailbox (required)
skip_password: Option<bool>True if Skipping Password (Boolean: 1/0) (required)
email: Option<String>Email address for receiving messages, multiple email addresses are allowed if separated by a comma
attach_message: Option<bool>Yes for Attaching WAV files to Message (Values: ‘yes’/‘no’) (required)
delete_message: Option<bool>Yes for Deleting Messages (Values: ‘yes’/‘no’) (required)
say_time: Option<bool>Yes for Saying Time Stamp (Values: ‘yes’/‘no’) (required)
timezone: Option<String>Time Zone for Mailbox (Values from getTimeZones) (required)
say_callerid: Option<bool>Yes for Saying the Caller ID (Values: ‘yes’/‘no’) (required)
play_instructions: Option<PlayInstructions>Code for Play Instructions Setting (Values from getPlayInstructions) (required)
language: Option<String>Code for Language (Values from getLanguages) (required)
email_attachment_format: Option<EmailAttachmentFormat>Code for Email Attachment format (Values from getVoicemailAttachmentFormats)
Recording for the Unavailable Message (values from getRecordings)
transcription: Option<bool>‘yes’ to enable Voicemail Transcription
transcription_locale: Option<String>Transcription locale code (values from getLocales, comma separated for more than one locale up to 10 locales)
transcription_redaction: Option<bool>Yes for Transcription redaction (Values: ‘yes’/‘no’)
transcription_sentiment: Option<bool>Yes for Transcription sentiment (Values: ‘yes’/‘no’)
transcription_summary: Option<bool>Yes for Transcription summary (Values: ‘yes’/‘no’)
transcription_format: Option<TranscriptionFormat>Transcription format ( Values: ‘html’/‘text’)