pub struct E911UpdateParams {
pub did: Option<String>,
pub full_name: Option<String>,
pub street_number: Option<i64>,
pub street_name: Option<String>,
pub address_type: Option<String>,
pub address_number: Option<i64>,
pub city: Option<String>,
pub state: Option<String>,
pub country: Option<String>,
pub zip: Option<String>,
pub language: Option<String>,
pub other_info: Option<String>,
}Expand description
- Updates the Information from your e911 Emergency Services Subscription.
Parameters for Client::e911_update (wire method e911Update).
Fields
did: Option<String>DID with e911 enabled / in process. (required)
full_name: Option<String>Full Name that will be updated to the e911 service. (required)
street_number: Option<i64>Street Number that will be updated to the e911 service. (required)
street_name: Option<String>Street Name that will be updated to the e911 service. (required)
address_type: Option<String>Address Type that will be updated to the e911 service (Values from e911AddressTypes).
address_number: Option<i64>Address Number that will be updated to the e911 service.
city: Option<String>City that will be updated to the e911 service. (required)
state: Option<String>State / Province that will be updated to the e911 service. (required)
country: Option<String>Country that will be updated to the e911 service. Value can be US (United states) or CA (Canada). (required)
zip: Option<String>language: Option<String>Language that will be updated to the e911 service. Only available for addresses from Canada. Value can be EN (English) or FR (French). (required)
other_info: Option<String>Additional Address Information that will be updated to the e911 service. Only available for addresses from Canada.