pub struct GetAllowedCodecsParams {
pub codec: Option<String>,
}Expand description
- Retrieves a list of Allowed Codecs if no additional parameter is provided. - Retrieves a specific Allowed Codec if a codec code is provided.
Parameters for Client::get_allowed_codecs (wire method getAllowedCodecs).
Fields
codec: Option<String>Code for a specific Codec (Example: ‘ulaw’)