pub struct GetCallbacksParams {
pub callback: Option<String>,
}Expand description
- Retrieves a list of Callbacks if no additional parameter is provided. - Retrieves a specific Callback if a Callback code is provided.
Parameters for Client::get_callbacks (wire method getCallbacks).
Fields
callback: Option<String>ID for a specific Callback (Example: 2359)