pub struct GetFAXNumbersPortabilityParams {
pub did: Option<i64>,
}Expand description
- Shows if a Fax Number can be ported into our network
Parameters for Client::get_fax_numbers_portability (wire method getFaxNumbersPortability).
Fields
did: Option<i64>DID Number to be ported into our network (Example: 5552341234) (required)