pub struct GetPlayInstructionsParams {
pub play_instructions: Option<PlayInstructions>,
}Expand description
- Retrieves a list of Play Instructions modes if no additional parameter is provided. - Retrieves a specific Play Instructions mode if a play code is provided.
Parameters for Client::get_play_instructions (wire method getPlayInstructions).
Fields
play_instructions: Option<PlayInstructions>Code for a specific Play Instructions setting (Example: ‘u’)