pub struct GetStaticMembersParams {
pub queue: Option<String>,
pub member: Option<String>,
}Expand description
- Retrieves a list of Static Members from a queue if no additional parameter is provided. - Retrieves a specific Static Member from a queue if Queue ID and Member ID are provided
Parameters for Client::get_static_members (wire method getStaticMembers).
Fields
queue: Option<String>ID for a specific Queue (Example: 4136) (required)
member: Option<String>ID for a specific Static Member (Example: 163) - The Member must belong to the queue provided