pub struct GetSubAccountsParams {
pub account: Option<String>,
}Expand description
- Retrieves all Sub Accounts if no additional parameter is provided. - Retrieves Reseller Client Accounts if Reseller Client ID is provided. - Retrieves a specific Sub Account if a Sub Account is provided.
Parameters for Client::get_sub_accounts (wire method getSubAccounts).
Fields
account: Option<String>Parameter could have the following values: * Empty Value [Not Required] * Specific Sub Account (Example: ‘100000_VoIP’) * Specific Reseller Client ID (Example: 561115)