OrderDIDVirtualParams

Struct OrderDIDVirtualParams 

pub struct OrderDIDVirtualParams {
Show 16 fields pub digits: Option<i64>, pub routing: Option<Routing>, pub failover_busy: Option<Routing>, pub failover_unreachable: Option<Routing>, pub failover_noanswer: Option<Routing>, pub voicemail: Option<String>, pub pop: Option<i64>, pub dialtime: Option<i64>, pub cnam: Option<String>, pub callerid_prefix: Option<String>, pub note: Option<String>, pub account: Option<String>, pub monthly: Option<String>, pub setup: Option<String>, pub minute: Option<String>, pub test: bool,
}
- Orders and Adds a new Virtual DID Number to the Account.

Parameters for Client::order_did_virtual (wire method orderDIDVirtual).

Fields

digits: Option<i64>

Three Digits for the new Virtual DID (Example: 001) (required)

routing: Option<Routing>

Main Routing for the DID (required)

failover_busy: Option<Routing>

Busy Routing for the DID

failover_unreachable: Option<Routing>

Unreachable Routing for the DID

failover_noanswer: Option<Routing>

NoAnswer Routing for the DID

voicemail: Option<String>

Voicemail for the DID (Example: 101)

pop: Option<i64>

Point of Presence for the DID (Example: 5) (required)

dialtime: Option<i64>

Dial Time Out for the DID (Example: 60 -> in seconds) (required)

cnam: Option<String>

CNAM for the DID (Boolean: 1/0) (required)

callerid_prefix: Option<String>

Caller ID Prefix for the DID

note: Option<String>

Note for the DID

account: Option<String>

Reseller Sub Account (Example: ‘100001_VoIP’)

monthly: Option<String>

Montly Fee for Reseller Client (Example: 3.50)

setup: Option<String>

Setup Fee for Reseller Client (Example: 1.99)

minute: Option<String>

Minute Rate for Reseller Client (Example: 0.03)

test: bool

Set to true if testing how Orders work - Orders can not be undone - When testing, no Orders are made routing, failover_busy, failover_unreachable and failover_noanswer can receive values in the following format => header:record_id Where header could be: account, fwd, vm, sip, grp, ivr, sys, recording, queue, cb, tc, disa, none. Examples: account Used for routing calls to Sub Accounts You can get all sub accounts using the getSubAccounts function fwd Used for routing calls to Forwarding entries. You can get the ID right after creating a Forwarding with setForwarding or by requesting all forwardings entries with getForwardings. vm Used for routing calls to a Voicemail. You can get all voicemails and their IDs using the getVoicemails function sys System Options: hangup = Hangup the Call busy = Busy tone noservice = System Recording: Number not in service disconnected = System Recording: Number has been disconnected dtmf = DTMF Test echo = Sound Quality Test none Used to route calls to no action Examples: ‘account:100001_VoIP’ ‘fwd:1026’ ‘vm:101’ ‘none:’ ‘sys:echo’