pub struct OrderFAXNumberParams {
pub location: Option<i64>,
pub quantity: Option<i64>,
pub email: Option<String>,
pub email_enable: Option<bool>,
pub email_attach_file: Option<bool>,
pub url_callback: Option<String>,
pub url_callback_enable: Option<bool>,
pub url_callback_retry: Option<bool>,
pub test: bool,
}Expand description
- Orders and Adds a new Fax Number to the Account.
Parameters for Client::order_fax_number (wire method orderFaxNumber).
Fields
location: Option<i64>Location ID of the Fax Number (Values from getFaxRateCentersCAN/getFaxRateCentersUSA) (required)
quantity: Option<i64>Quantity of Fax Numbers to order (Example: 3) (required)
email: Option<String>Email address where send notifications when receive Fax Messages - (Example: [email protected])
email_enable: Option<bool>Flag to enable the email notifications. - (Values: 1 = true, 0 = false) - Default: 0
email_attach_file: Option<bool>Flag to enable attach the Fax Message as a PDF file in the notifications. - (Values: 1 = true, 0 = false) - Default: 0
url_callback: Option<String>URL where make a POST when you receive a Fax Message.
url_callback_enable: Option<bool>Flag to enable the URL Callback functionality. - (Values: 1 = true, 0 = false) - Default: 0
url_callback_retry: Option<bool>Flag to enable retry the POST action in case we don’t receive “ok”.
test: boolSet to true if testing how Orders work - Orders can not be undone - When testing, no Orders are made