pub struct SendFAXMessageParams {
pub to_number: Option<String>,
pub from_name: Option<String>,
pub from_number: Option<String>,
pub send_email_enabled: Option<bool>,
pub send_email: Option<String>,
pub station_id: Option<String>,
pub file: Option<String>,
pub test: bool,
}Expand description
- Send a Fax message to a Destination Number.
Parameters for Client::send_fax_message (wire method sendFaxMessage).
Fields
to_number: Option<String>Destination DID Number (Example: 5552341234) (required)
from_name: Option<String>Name of the sender (Example: 5552341234) (required)
from_number: Option<String>DID number of the Fax sender (required)
send_email_enabled: Option<bool>Flag to enable the send of a copy of your Fax via email. - (Values: 1 = true, 0 = false) - Default: 0
send_email: Option<String>Email address where you want send a copy of your Fax.
station_id: Option<String>An word to identify a equipment or department sending the Fax.
file: Option<String>The file must be encoded in Base64, and in one of the following formats: pdf, txt, jpg, gif, png, tif (required)
test: boolSet to true if testing how to send a Fax Message