SetCallParkingParams

Struct SetCallParkingParams 

pub struct SetCallParkingParams {
    pub callparking: Option<i64>,
    pub name: Option<String>,
    pub timeout: Option<i64>,
    pub music: Option<String>,
    pub failover: Option<String>,
    pub language: Option<String>,
    pub destination: Option<String>,
    pub delay: Option<i64>,
}
- Updates a specific Call Parking entry if a Call Parking ID is provided. - Adds a new Call Parking entry if no Call Parking ID is provided.

Parameters for Client::set_call_parking (wire method setCallParking).

Fields

callparking: Option<i64>

ID for a specific Call Parking (Example: 235 / Leave empty to create a new one)

name: Option<String>

Name for the Call Parking (required)

timeout: Option<i64>

The number of seconds a call will stay parked before it is forwarded to the Failover Destination (required)

music: Option<String>

Music on Hold Code (Values from getMusicOnHold) (required)

failover: Option<String>

Final destination where the call will be forwarded if it isn’t answered. (Values: callback, system:hangup, vm:mailbox) (required)

language: Option<String>

Language for the Call Parking (values from getLanguages) (required)

destination: Option<String>

The system will make an automatic call to this destination to announce the extension of the parked call. (Values: parker, main account or sub-accounts) (required)

delay: Option<i64>

The number of seconds before the Announce Destination receives an automatic call from the system to announce the extension of the parked call (required)