pub struct SetCallbackParams {
pub callback: Option<String>,
pub description: Option<String>,
pub number: Option<i64>,
pub delay_before: Option<i64>,
pub response_timeout: Option<i64>,
pub digit_timeout: Option<i64>,
pub callerid_number: Option<String>,
}Expand description
- Updates a specific Callback if a callback code is provided. - Adds a new Callback entry if no callback code is provided.
Parameters for Client::set_callback (wire method setCallback).
Fields
callback: Option<String>ID for a specific Callback (Example: 2359 / Leave empty to create a new one)
description: Option<String>Description for the Callback (required)
number: Option<i64>Number that will be called back (required)
delay_before: Option<i64>Delay befor calling back (required)
response_timeout: Option<i64>Time before hanging up for incomplete input (required)
digit_timeout: Option<i64>Time between digits input (required)
callerid_number: Option<String>Caller ID Override for the callback