SetConferenceMemberParams

Struct SetConferenceMemberParams 

pub struct SetConferenceMemberParams {
Show 18 fields pub member: Option<i64>, pub conference: Option<i64>, pub name: Option<String>, pub description: Option<String>, pub pin: Option<i64>, pub announce_join_leave: Option<bool>, pub admin: Option<bool>, pub start_muted: Option<bool>, pub announce_user_count: Option<bool>, pub announce_only_user: Option<bool>, pub moh_when_empty: Option<String>, pub quiet: Option<bool>, pub announcement: Option<i64>, pub drop_silence: Option<bool>, pub talking_threshold: Option<i64>, pub silence_threshold: Option<i64>, pub talk_detection: Option<bool>, pub jitter_buffer: Option<bool>,
}
- Updates a specific Member profile if a member code is provided. - Adds a new Member profile entry if no member code is provided.

Parameters for Client::set_conference_member (wire method setConferenceMember).

Fields

member: Option<i64>

ID for a specific Member profile (Example: 5356) (required)

conference: Option<i64>

ID for a specific Conference (Example: 5356) (required)

name: Option<String>

Member name. (required)

description: Option<String>

Member description.

pin: Option<i64>

Assigned PIN.

announce_join_leave: Option<bool>

Sets if the conference recording when a member joins or leaves will be played (yes/no).

admin: Option<bool>

Sets if the member is an admin or not (yes/no).

start_muted: Option<bool>

Sets if the member should start out muted after entering the conference (yes/no).

announce_user_count: Option<bool>

Sets if the number of members in the conference should be announced to the caller as he joins (yes/no).

announce_only_user: Option<bool>

Sets if the “only user” announcement should be played when a caller enters an empty conference (yes/no).

moh_when_empty: Option<String>

Sets whether music on hold (MOH) should be played when only one person is in the conference (Values from getMusicOnHold).

quiet: Option<bool>

When set to “yes”, enter/leave prompts and user introductions are not played (yes/no).

announcement: Option<i64>

If set, this recording will be heard only by the user as he joins the conference (Values from getRecordings).

drop_silence: Option<bool>

The system will drop what is detected as silence from entering into the conference (yes/no).

talking_threshold: Option<i64>

The time, in milliseconds, that a users needs to be sending sound or voice before the system can consider them to be talking (allowed values are 100, 120, 140, 160, 180, 200, 220, 240 or 250).

silence_threshold: Option<i64>

The time, in milliseconds, that silence needs to be present in the user’s sound stream before the system can consider it to be in fact silent and close the audio (allowed values are 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900 or 3000).

talk_detection: Option<bool>

If set to YES, the conference dashboard will display a notification when a participant starts and stops talking (yes/no).

jitter_buffer: Option<bool>

When set to YES, the system will place a jitter buffer on the caller’s audio stream before any audio mixing is performed (yes/no).