pub struct SetFAXNumberEmailParams {
pub did: Option<i64>,
pub email: Option<String>,
pub email_enable: Option<bool>,
pub email_attach_file: Option<bool>,
pub test: bool,
}Expand description
- Updates the email configuration from a specific Fax Number.
Parameters for Client::set_fax_number_email (wire method setFaxNumberEmail).
Fields
did: Option<i64>DID Number to be ported into our network (Example: 5552341234) (required)
email: Option<String>Email address where send notifications when receive Fax Messages - (Example: [email protected])
email_enable: Option<bool>Flag to enable the email notifications. - (Values: 1 = true, 0 = false) - Default: 0
email_attach_file: Option<bool>Flag to enable attach the Fax Message as a PDF file in the notifications. - (Values: 1 = true, 0 = false) - Default: 0
test: boolSet to true if testing how to set the email of a Fax Number