pub struct SetFAXNumberInfoParams {
pub did: Option<i64>,
pub email: Option<String>,
pub email_enable: Option<bool>,
pub email_attach_file: Option<bool>,
pub url_callback: Option<String>,
pub url_callback_enable: Option<bool>,
pub url_callback_retry: Option<bool>,
pub test: bool,
}Expand description
- Updates the information from a specific Fax Number.
Parameters for Client::set_fax_number_info (wire method setFaxNumberInfo).
Fields
did: Option<i64>DID Number to be ported into our network (Example: 5552341234) (required)
email: Option<String>Email address where send notifications when receive Fax Messages - (Example: [email protected])
email_enable: Option<bool>Flag to enable the email notifications. - (Values: 1 = true, 0 = false) - Default: 0
email_attach_file: Option<bool>Flag to enable attach the Fax Message as a PDF file in the notifications. - (Values: 1 = true, 0 = false) - Default: 0
url_callback: Option<String>URL where make a POST when you receive a Fax Message.
url_callback_enable: Option<bool>Flag to enable the URL Callback functionality. - (Values: 1 = true, 0 = false) - Default: 0
url_callback_retry: Option<bool>Flag to enable retry the POST action in case we don’t receive “ok”.
test: boolSet to true if testing how to update the information of a Fax Number