pub struct SetPhonebookParams {
pub phonebook: Option<String>,
pub speed_dial: Option<String>,
pub name: Option<String>,
pub number: Option<i64>,
pub callerid: Option<String>,
pub note: Option<String>,
pub group: Option<i64>,
}Expand description
- Updates a specific Phonebook entry if a phonebook code is provided. - Adds a new Phonebook entry if no phonebook code is provided.
Parameters for Client::set_phonebook (wire method setPhonebook).
Fields
phonebook: Option<String>ID for a specific Phonebook entry (Example: 32207 / Leave empty to create a new one)
speed_dial: Option<String>Speed Dial for the Phonebook entry
name: Option<String>Name for the Phonebook Entry (required)
number: Option<i64>Number or SIP for the Phonebook entry (Example: ‘sip:2563’ or ‘5552223333’) (required)
callerid: Option<String>Caller ID Override when dialing via Speed Dial
note: Option<String>Note for the phonebook entry
group: Option<i64>ID for a specific Phonebook group