pub struct SetQueueParams {Show 33 fields
pub queue: Option<String>,
pub queue_name: Option<String>,
pub queue_number: Option<i64>,
pub queue_language: Option<String>,
pub queue_password: Option<String>,
pub callerid_prefix: Option<i64>,
pub join_announcement: Option<String>,
pub priority_weight: Option<String>,
pub agent_announcement: Option<String>,
pub report_hold_time_agent: Option<String>,
pub member_delay: Option<Seconds>,
pub maximum_wait_time: Option<WaitTime>,
pub maximum_callers: Option<String>,
pub join_when_empty: Option<QueueEmptyBehavior>,
pub leave_when_empty: Option<QueueEmptyBehavior>,
pub ring_strategy: Option<RingStrategy>,
pub ring_inuse: Option<bool>,
pub agent_ring_timeout: Option<i64>,
pub retry_timer: Option<Seconds>,
pub wrapup_time: Option<Seconds>,
pub voice_announcement: Option<String>,
pub frequency_announcement: Option<Seconds>,
pub announce_position_frecuency: Option<Seconds>,
pub announce_round_seconds: Option<Seconds>,
pub if_announce_position_enabled_report_estimated_hold_time: Option<EstimatedHoldTimeAnnounce>,
pub thankyou_for_your_patience: Option<bool>,
pub music_on_hold: Option<String>,
pub fail_over_routing_timeout: Option<Routing>,
pub fail_over_routing_full: Option<Routing>,
pub fail_over_routing_join_empty: Option<Routing>,
pub fail_over_routing_leave_empty: Option<Routing>,
pub fail_over_routing_join_unavail: Option<Routing>,
pub fail_over_routing_leave_unavail: Option<Routing>,
}Expand description
- Updates a specific Queue entry if a queue code is provided. - Adds a new Queue entry if no queue code is provided.
Parameters for Client::set_queue (wire method setQueue).
Fields
queue: Option<String>ID for a specific Queue entry (Example: 32208 / Leave empty to create a new one)
queue_name: Option<String>Queue entry name (required)
queue_number: Option<i64>Queue entry number (required)
queue_language: Option<String>Language Code (Values from getLanguages) (required)
queue_password: Option<String>Queue Password
callerid_prefix: Option<i64>Caller ID Prefix for queue
join_announcement: Option<String>Recording Code (Values from getRecordings or ‘none’)
priority_weight: Option<String>weight/priority of queue (Values 1 to 60) (required)
agent_announcement: Option<String>Recording Code (Values from getRecordings or ‘none’)
report_hold_time_agent: Option<String>Report hold time to agent (Values from getReportEstimatedHoldTime) (required)
member_delay: Option<Seconds>Member delay when the agent is connected to the caller (Values 1 to 15 in seconds or ‘none’)
maximum_wait_time: Option<WaitTime>Ammount of time a caller can wait in queue (Values in seconds: multiples of 30, max value: 1200 or ‘unlimited’)
maximum_callers: Option<String>Maximum callers (Values: 1 to 60 or ‘unlimited’)
join_when_empty: Option<QueueEmptyBehavior>How caller join to the queue (Values from getJoinWhenEmptyTypes) Examples: yes Callers can join a queue with no members or only unavailable members no Callers cannot join a queue with no members strict Callers cannot join a queue with no members or only unavailable members (required)
leave_when_empty: Option<QueueEmptyBehavior>How caller leave the queue (Values ‘yes’/‘no’/‘strict’) Examples: yes Callers are sent to failover when there are no members no Callers will remain in the queue even if there are no members strict Callers are sent to failover if there are members but none of them is available. (required)
ring_strategy: Option<RingStrategy>Ring strategy (Values from getRingStrategies) (required)
ring_inuse: Option<bool>If you want the queue to avoid sending calls to members (Values ‘yes’/‘no’) (required)
agent_ring_timeout: Option<i64>Number of seconds to ring an agent (Values 5 to 60)
retry_timer: Option<Seconds>How long do we wait before trying all the members again (Values 5 to 60 seconds or ‘none’= No Delay)
wrapup_time: Option<Seconds>After a successful call, the number of seconds to wait before sending a free agent another call (Values 1 to 60 seconds or ‘none’= No Delay)
voice_announcement: Option<String>Code for Recording (Values from getRecordings or ‘none’)
frequency_announcement: Option<Seconds>Periodic interval to play voice announce recording (Values in seconds: multiples of 15, max value: 1200 or ‘none’ = No announcement)
announce_position_frecuency: Option<Seconds>How often to make any periodic announcement (Values in seconds: multiples of 15, max value: 1200 or ‘none’ = No announcement)
announce_round_seconds: Option<Seconds>Announce seconds (Values in seconds: 1 to 60 or ‘none’ = Do not announce)
if_announce_position_enabled_report_estimated_hold_time: Option<EstimatedHoldTimeAnnounce>Include estimated hold time in position announcements (Values ‘yes’/‘no’/‘once’)
thankyou_for_your_patience: Option<bool>Yes to say “Thank you for your patience” immediatly after announcing Queue Position and Estimated hold time left (Values ‘yes’/‘no’)
music_on_hold: Option<String>Music on Hold Code (Values from getMusicOnHold)
fail_over_routing_timeout: Option<Routing>Failover routing to Maximum wait time reached
fail_over_routing_full: Option<Routing>Failover routing to Maximum callers reached
fail_over_routing_join_empty: Option<Routing>A call was sent to the queue but the queue had no members (Only works when Join when Empty is set to no)
fail_over_routing_leave_empty: Option<Routing>The last agent was removed form the queue before alls calls were handled (Only works when Leave when Empty is set to yes)
Same as routingjoinempty, except that there were still queue members, but all were status unavailable
Same as routingleaveempty, except that there were still queue members, but all were status unavailable routings can receive values in the following format => header:record_id Where header could be: account, fwd, vm, sip, grp, ivr, sys, recording, queue, cb, tc, disa, none. Examples: account Used for routing calls to Sub Accounts You can get all sub accounts using the getSubAccounts function fwd Used for routing calls to Forwarding entries. You can get the ID right after creating a Forwarding with setForwarding or by requesting all forwardings entries with getForwardings. vm Used for routing calls to a Voicemail. You can get all voicemails and their IDs using the getVoicemails function Examples: ‘account:100001_VoIP’ ‘fwd:1026’ ‘vm:101’