SetRecordingParams

Struct SetRecordingParams 

pub struct SetRecordingParams {
    pub recording: Option<String>,
    pub file: Option<String>,
    pub name: Option<String>,
}
- Updates a specific Recording File if a Recording ID is provided. - Adds a new Recording file entry if no Recording ID is provided.

Parameters for Client::set_recording (wire method setRecording).

Fields

recording: Option<String>

ID for a specific Phonebook entry (Example: 33221 / Leave empty to create a new one)

file: Option<String>

Base64 encoded file (Provide Recording ID and file if you want update the file only) (required)

name: Option<String>

Name for the Recording Entry (Example: ‘recording1’) (Provide Recording ID and name if you want update the name only) (Provide Recording ID, file and name if you want update both parameters at the same time) (required)