pub struct SetRingGroupParams {
pub ring_group: Option<String>,
pub name: Option<String>,
pub members: Option<String>,
pub voicemail: Option<String>,
pub caller_announcement: Option<String>,
pub music_on_hold: Option<String>,
pub language: Option<String>,
}Expand description
- Updates a specific Ring Group if a ring group code is provided. - Adds a new Ring Group entry if no ring group code is provided.
Parameters for Client::set_ring_group (wire method setRingGroup).
Fields
ring_group: Option<String>ID for a specific Ring Group (Example: 4768 / Leave empty to create a new one)
name: Option<String>Name for the Ring Group (required)
members: Option<String>Members for the Ring Group (Example: ‘account:100001;fwd:16006’) (required)
voicemail: Option<String>Voicemail for the Ring Group (Values from getVoicemails) (required)
caller_announcement: Option<String>Recording Code (Values from getRecordings)
music_on_hold: Option<String>Music on Hold Code (Values from getMusicOnHold)
language: Option<String>Code for Language (Values from getLanguages) “members” can receive the following routing headers: account Used to route the call to an Account or a Sub Account fwd Used to route the call to a Forwarding entry sip Used to route the call to a SIP URI Each member can a specific ring time and press1 values, you can add those to the routing header as follow: Example: ‘account:100001,25,0;fwd:16006,10,1’ 25 = Default ring time value (Values from 1 to 60 sec) 0 = Default press1 value (Values allowed 0 and 1)