SetSMSParams

Struct SetSMSParams 

pub struct SetSMSParams {
    pub did: Option<String>,
    pub enable: Option<bool>,
    pub email_enabled: Option<bool>,
    pub email_address: Option<String>,
    pub sms_forward_enable: Option<bool>,
    pub sms_forward: Option<String>,
    pub url_callback_enable: Option<bool>,
    pub url_callback: Option<String>,
    pub url_callback_retry: Option<bool>,
    pub sms_sipaccount: Option<String>,
    pub sms_sipaccount_enabled: Option<bool>,
}
- Enable/Disable the SMS Service for a DID - Change the SMS settings for a DID

Parameters for Client::set_sms (wire method setSMS).

Fields

did: Option<String>

DID to be Updated (Example: 5551234567) (required)

enable: Option<bool>

Enable/Disable the DID to receive SMS Messages (Values: 1=Enable / 0=Disable) (required)

email_enabled: Option<bool>

If Enable, SMS Messages received by your DID will be sent to the email address provided (Values: 1=Enable / 0=Disable)

email_address: Option<String>

SMS Messages received by your DID will be sent to the email address provided

sms_forward_enable: Option<bool>

If Enable, SMS Messages received by your DID will be forwarded to the phone number provided (Values: 1=Enable / 0=Disable)

sms_forward: Option<String>

SMS Messages received by your DID will be forwarded to the phone number provided (Example: 5551234567)

url_callback_enable: Option<bool>

If Enable, SMS Messages received by your DID will be send a GET request to the URL callback provided (Values: 1=Enable / 0=Disable)

url_callback: Option<String>

SMS Messages received by your DID will be send a GET request to the URL callback provided Available Variables for your URL {FROM} The phone number that sent you the message. {TO} The DID number that received the message. {MESSAGE} The content of the message. Example: http://mysite.com/sms.php?to={TO}&from={FROM}&message={MESSAGE}

url_callback_retry: Option<bool>

Enable URL callback Retry (Values: 1=Enable / 0=Disable) we will be expecting an ‘ok’ output (without quotes) from your URL callback page as an indicator that you have received the message correctly. If we don’t receive the ‘ok’ letters (wihtout quotes) from your callback page, we will keep sending you the same message every 30 minutes.

sms_sipaccount: Option<String>

SIP account or sub-account that will receive the SMS Messages

sms_sipaccount_enabled: Option<bool>

If Enable, SMS Messages received by your DID will be sent to the specified SIP account or sub-account (Values: 1=Enable / 0=Disable)