pub struct SetStaticMemberParams {
pub member: Option<String>,
pub queue: Option<i64>,
pub member_name: Option<String>,
pub account: Option<String>,
pub priority: Option<i64>,
}Expand description
- Updates a specific Member from queue if a Member code is provided. - Adds a new Member to Queue if no Member code is provided.
Parameters for Client::set_static_member (wire method setStaticMember).
Fields
member: Option<String>ID for a specific Member (Example: 619 / Leave empty to create a new one)
queue: Option<i64>ID for a specific Queue (required)
member_name: Option<String>Member Description (required)
account: Option<String>Static Member Routing to receive calls - You can get all sub accounts using the getSubAccounts function
priority: Option<i64>Values for get calls first (Example: 0) (required)