pub struct SetCallHuntingParams {
pub callhunting: Option<i64>,
pub description: Option<String>,
pub music: Option<String>,
pub recording: Option<String>,
pub language: Option<String>,
pub order: Option<RingGroupOrder>,
pub members: Option<String>,
pub ring_time: Option<String>,
pub press: Option<String>,
}Expand description
- Updates a specific Call Hunting if a Call Hunting code is provided. - Adds a new Call Hunting if no Call Hunting code is provided.
Parameters for Client::set_call_hunting (wire method setCallHunting).
Fields
callhunting: Option<i64>ID for a specific Call Hunting (Example: 235 / Leave empty to create a new one)
description: Option<String>Description for the Call Hunting (required)
music: Option<String>Music on Hold Code (Values from getMusicOnHold) (required)
recording: Option<String>Recording for the Call Hunting (values from getRecordings) (required)
language: Option<String>Language for the Call Hunting (values from getLanguages) (required)
order: Option<RingGroupOrder>The members will be called in follow or random order (values follow or random) (required)
members: Option<String>The list of members assigned to the call hunting (required)
ring_time: Option<String>The Maximum amount of time the call will ring the member (required)
press: Option<String>This option confirm if the member will take the call by pressing 1 * ring_time and press parameters need to have the same amount of items as the members parameter, one for each member. (required)