pub struct SetConferenceParams {Show 26 fields
pub conference: Option<i64>,
pub name: Option<String>,
pub description: Option<String>,
pub members: Option<String>,
pub max_members: Option<String>,
pub sound_join: Option<String>,
pub sound_leave: Option<String>,
pub sound_has_joined: Option<String>,
pub sound_has_left: Option<String>,
pub sound_kicked: Option<String>,
pub sound_muted: Option<String>,
pub sound_unmuted: Option<String>,
pub sound_only_person: Option<String>,
pub sound_only_one: Option<String>,
pub sound_there_are: Option<String>,
pub sound_other_in_party: Option<String>,
pub sound_place_into_conference: Option<String>,
pub sound_get_pin: Option<String>,
pub sound_invalid_pin: Option<String>,
pub sound_locked: Option<String>,
pub sound_locked_now: Option<String>,
pub sound_unlocked_now: Option<String>,
pub sound_error_menu: Option<String>,
pub sound_participants_muted: Option<String>,
pub sound_participants_unmuted: Option<String>,
pub language: Option<String>,
}Expand description
- Updates a specific Conference if a conference code is provided. - Adds a new Conference entry if no conference code is provided.
Parameters for Client::set_conference (wire method setConference).
Fields
conference: Option<i64>ID for a specific Conference (Example: 5356) (required)
name: Option<String>Conference name (required)
description: Option<String>Conference description (required)
members: Option<String>Conference Members
max_members: Option<String>Members Max Value (required)
sound_join: Option<String>The recording played when a user joins, typically some kind of beep sound (Values from getRecordings)
sound_leave: Option<String>The recording played when a user leaves, typically some kind of beep sound (Values from getRecordings)
sound_has_joined: Option<String>The recording played as a user intro (Values from getRecordings)
sound_has_left: Option<String>The recording played as a user leaves the conference (Values from getRecordings)
sound_kicked: Option<String>The recording played to a user who has been kicked from the conference (Values from getRecordings)
sound_muted: Option<String>The recording played to a user when the mute option is toggled on (Values from getRecordings)
sound_unmuted: Option<String>The recording played to a user when the mute option is toggled off (Values from getRecordings)
sound_only_person: Option<String>The recording played when a user is the only person in the conference (Values from getRecordings)
sound_only_one: Option<String>The recording played to a user when there is only one other person in the conference. (Values from getRecordings)
sound_there_are: Option<String>The recording played when announcing how many users there are in a conference. (Values from getRecordings)
sound_other_in_party: Option<String>The recording used in conjunction with the There are option, used like There are (number of participants) Other in party (Values from getRecordings)
sound_place_into_conference: Option<String>The recording played when a user is placed into a conference that cannot start until a marked user enters (Values from getRecordings)
sound_get_pin: Option<String>The recording played when prompting for a conference PIN (Values from getRecordings)
sound_invalid_pin: Option<String>The recording played when an invalid PIN is entered too many (3) times (Values from getRecordings)
sound_locked: Option<String>The recording played to a user trying to join a locked conference (Values from getRecordings)
sound_locked_now: Option<String>The recording played to an Admin-level user after toggling the conference to locked mode (Values from getRecordings)
sound_unlocked_now: Option<String>The recording played to an Admin-level user after toggling the conference to unlocked mode (Values from getRecordings)
The recording played when there is an error on the menu. (Values from getRecordings)
sound_participants_muted: Option<String>The recording played when all non-admin participants are muted. (Values from getRecordings)
sound_participants_unmuted: Option<String>The recording played when all non-admin participants are unmuted. (Values from getRecordings)
language: Option<String>Conference Language (Values from getLanguages)