pub struct SetDIDInfoParams {Show 19 fields
pub did: Option<String>,
pub routing: Option<Routing>,
pub failover_busy: Option<Routing>,
pub failover_unreachable: Option<Routing>,
pub failover_noanswer: Option<Routing>,
pub voicemail: Option<String>,
pub pop: Option<i64>,
pub dialtime: Option<i64>,
pub cnam: Option<i64>,
pub callerid_prefix: Option<String>,
pub note: Option<String>,
pub port_out_pin: Option<i64>,
pub billing_type: Option<DidBillingType>,
pub record_calls: Option<bool>,
pub transcribe: Option<bool>,
pub transcription_locale: Option<String>,
pub transcription_email: Option<String>,
pub transcription_start_delay: Option<i64>,
pub voicemail_threshold: Option<i64>,
}Expand description
- Updates the information from a specific DID.
Parameters for Client::set_did_info (wire method setDIDInfo).
Fields
did: Option<String>DID to be Updated (Example: 5551234567) (required)
routing: Option<Routing>Main Routing for the DID (required)
failover_busy: Option<Routing>Busy Routing for the DID
failover_unreachable: Option<Routing>Unreachable Routing for the DID
failover_noanswer: Option<Routing>NoAnswer Routing for the DID
voicemail: Option<String>Voicemail for the DID
pop: Option<i64>Point of Presence for the DID (“server_pop” values from getServersInfo. Example: 3) (required)
dialtime: Option<i64>Dial Time Out for the DID (Example: 60 -> in seconds) (required)
cnam: Option<i64>CNAM for the DID (Boolean: 1/0) (required)
callerid_prefix: Option<String>Caller ID Prefix for the DID
note: Option<String>Note for the DID
port_out_pin: Option<i64>Port Out PIN protection is used as a means of authorizing outgoing portability (only for selected US numbers with the lock icon)
billing_type: Option<DidBillingType>Billing type for the DID (1 = Per Minute, 2 = Flat) (required)
record_calls: Option<bool>Record Calls (Boolean: 1/0)
transcribe: Option<bool>Enable Call Transcription (Boolean: 1/0)
transcription_locale: Option<String>Transcription locale code (values from getLocales, comma separated for more than one locale up to 10 locales)
transcription_email: Option<String>Call Transcription Email
transcription_start_delay: Option<i64>Call Transcription Delay Seconds between 0 and 60, Increments of 5 (Example: 10 -> seconds)
voicemail_threshold: Option<i64>Voicemail Threshold Seconds between 0 and 60, Increments of 5 (Example: 10 -> seconds) routing, failover_busy, failover_unreachable and failover_noanswer can receive values in the following format => header:record_id Where header could be: account, fwd, vm, sip, grp, ivr, sys, recording, queue, cb, tc, disa, none. Examples: account Used for routing calls to Sub Accounts You can get all sub accounts using the getSubAccounts function fwd Used for routing calls to Forwarding entries. You can get the ID right after creating a Forwarding with setForwarding or by requesting all forwardings entries with getForwardings. vm Used for routing calls to a Voicemail. You can get all voicemails and their IDs using the getVoicemails function sys System Options: hangup = Hangup the Call busy = Busy tone noservice = System Recording: Number not in service disconnected = System Recording: Number has been disconnected dtmf = DTMF Test echo = Sound Quality Test none Used to route calls to no action Examples: ‘account:100001_VoIP’ ‘fwd:1026’ ‘vm:101’ ‘none:’ ‘sys:echo’