pub struct SetDIDRoutingParams {
pub did: Option<String>,
pub routing: Option<Routing>,
}Expand description
- Updates the Routing from a specific DID.
Parameters for Client::set_did_routing (wire method setDIDRouting).
Fields
did: Option<String>DID to be Updated (Example: 5551234567) (required)
routing: Option<Routing>Main Routing for the DID routing can receive values in the following format => header:record_id Where header could be: account, fwd, vm, sip, grp, ivr, sys, recording, queue, cb, tc, disa, none. Examples: account Used for routing calls to Sub Accounts You can get all sub accounts using the getSubAccounts function fwd Used for routing calls to Forwarding entries. You can get the ID right after creating a Forwarding with setForwarding or by requesting all forwardings entries with getForwardings. vm Used for routing calls to a Voicemail. You can get all voicemails and their IDs using the getVoicemails function Examples: ‘account:100001_VoIP’ ‘fwd:1026’ ‘vm:101’ (required)